@@ -71,81 +71,83 @@ static unsigned char nonbizdays = SUNDAY | SATURDAY;
 static bool use_easter = true;
 static bool use_great_friday = true;
 static bool include_start = true;
-static int country_id = -1;			/* unknown */
+static int	country_id = -1;	/* unknown */
 
 #define MAX_holidays   30
 #define MAX_EXCEPTIONS 50
 
-typedef struct {
-	char day;
-	char month;
+typedef struct
+{
+	char		day;
+	char		month;
 } holiday_desc;
 
-typedef struct {
+typedef struct
+{
 	unsigned char nonbizdays;
-	bool use_easter;
-	bool use_great_friday;
+	bool		use_easter;
+	bool		use_great_friday;
 	holiday_desc *holidays;
-	int holidays_c;
+	int			holidays_c;
 } cultural_info;
 
-static holiday_desc holidays[MAX_holidays];  /* sorted array */
-static DateADT exceptions[MAX_EXCEPTIONS];   /* sorted array */
+static holiday_desc holidays[MAX_holidays]; /* sorted array */
+static DateADT exceptions[MAX_EXCEPTIONS];	/* sorted array */
 
-static int holidays_c = 0;
-static int exceptions_c = 0;
+static int	holidays_c = 0;
+static int	exceptions_c = 0;
 
 static holiday_desc czech_holidays[] = {
-	{1,1}, // Novy rok
-	{1,5}, // Svatek prace
-	{8,5}, // Den osvobozeni
-	{5,7}, // Den slovanskych verozvestu
-	{6,7}, // Den upaleni mistra Jana Husa
-	{28,9}, // Den ceske statnosti
-	{28,10}, // Den vzniku samostatneho ceskoslovenskeho statu
-	{17,11}, // Den boje za svobodu a demokracii
-	{24,12}, // Stedry den
-	{25,12}, // 1. svatek vanocni
-	{26,12}  // 2. svatek vanocni
+	{1, 1}, //Novy rok
+	{1, 5}, //Svatek prace
+	{8, 5}, //Den osvobozeni
+	{5, 7}, //Den slovanskych verozvestu
+	{6, 7}, //Den upaleni mistra Jana Husa
+	{28, 9}, //Den ceske statnosti
+	{28, 10}, //Den vzniku samostatneho ceskoslovenskeho statu
+	{17, 11}, //Den boje za svobodu a demokracii
+	{24, 12}, //Stedry den
+	{25, 12}, //1. svatek vanocni
+	{26, 12} //2. svatek vanocni
 };
 
 
 static holiday_desc germany_holidays[] = {
-	{1,1},{1,5},{25,5},{4,6},{5,6},
-	{15,8},{3,10},{25,12},{26,12}
+	{1, 1}, {1, 5}, {25, 5}, {4, 6}, {5, 6},
+	{15, 8}, {3, 10}, {25, 12}, {26, 12}
 };
 
 static holiday_desc poland_holidays[] = {
-	{1,1},{1,5},{3,5},{15,6},{15,8},
-	{1,11},{11,11},{25,12},{26,12}
+	{1, 1}, {1, 5}, {3, 5}, {15, 6}, {15, 8},
+	{1, 11}, {11, 11}, {25, 12}, {26, 12}
 };
 
 static holiday_desc austria_holidays[] = {
-	{1,1},{6,1},{1,5},{25,5},{4,6},
-	{5,6},{15,6},{15,8},{26,10},{1,11},
-	{8,12},{25,12},{26,12}
+	{1, 1}, {6, 1}, {1, 5}, {25, 5}, {4, 6},
+	{5, 6}, {15, 6}, {15, 8}, {26, 10}, {1, 11},
+	{8, 12}, {25, 12}, {26, 12}
 };
 
 static holiday_desc slovakia_holidays[] = {
-	{1,1},{6,1},{1,5},{8,5},{5,7},
-	{29,8},{1,9},{15,9},{1,11},{17,11},
-	{24,12},{25,12},{26,12}
+	{1, 1}, {6, 1}, {1, 5}, {8, 5}, {5, 7},
+	{29, 8}, {1, 9}, {15, 9}, {1, 11}, {17, 11},
+	{24, 12}, {25, 12}, {26, 12}
 };
 
 static holiday_desc russian_holidays[] = {
-	{1,1},{2,1},{3,1},{4,1},{5,1},
-	{7,1},{23,2},{8,3},{1,5},{9,5},
-	{12,6}, {4,11}
+	{1, 1}, {2, 1}, {3, 1}, {4, 1}, {5, 1},
+	{7, 1}, {23, 2}, {8, 3}, {1, 5}, {9, 5},
+	{12, 6}, {4, 11}
 };
 
 static holiday_desc england_holidays[] = {
-	{1,1},{2,1},{1,5},{29,5},{28,8},
-	{25,12},{26,12}
+	{1, 1}, {2, 1}, {1, 5}, {29, 5}, {28, 8},
+	{25, 12}, {26, 12}
 };
 
 static holiday_desc usa_holidays[] = {
-	{1,1},{16,1},{20,2},{29,5},{4,7},
-	{4,9},{9,10},{11,11},{23,11},{25,12}
+	{1, 1}, {16, 1}, {20, 2}, {29, 5}, {4, 7},
+	{4, 9}, {9, 10}, {11, 11}, {23, 11}, {25, 12}
 };
 
 static cultural_info defaults_ci[] = {
@@ -159,37 +161,42 @@ static cultural_info defaults_ci[] = {
 	{SUNDAY | SATURDAY, false, false, usa_holidays, 10}
 };
 
-static STRING_PTR_FIELD_TYPE states[] = {
+static STRING_PTR_FIELD_TYPE states[] =
+{
 	"Czech", "Germany", "Poland",
-	"Austria", "Slovakia", "Russia",
-	"Gb", "Usa",
-	NULL,
+		"Austria", "Slovakia", "Russia",
+		"Gb", "Usa",
+		NULL,
 };
 
 static int
-dateadt_comp(const void* a, const void* b)
+dateadt_comp(const void *a, const void *b)
 {
-	DateADT *_a = (DateADT*)a;
-	DateADT *_b = (DateADT*)b;
+	DateADT    *_a = (DateADT *) a;
+	DateADT    *_b = (DateADT *) b;
 
 	return *_a - *_b;
 }
 
 static int
-holiday_desc_comp(const void* a, const void* b)
+holiday_desc_comp(const void *a, const void *b)
 {
-	int result;
-	if (0 == (result = ((holiday_desc*)a)->month - ((holiday_desc*)b)->month))
-		result = ((holiday_desc*)a)->day - ((holiday_desc*)b)->day;
+	int			result;
+
+	if (0 == (result = ((holiday_desc *) a)->month - ((holiday_desc *) b)->month))
+		result = ((holiday_desc *) a)->day - ((holiday_desc *) b)->day;
 
 	return result;
 }
 
 
 static void
-calc_easter_sunday(int year, int* dd, int* mm)
+calc_easter_sunday(int year, int *dd, int *mm)
 {
-	int b, d, e, q;
+	int			b,
+				d,
+				e,
+				q;
 
 	if (year < 1900 || year > 2099)
 		ereport(ERROR,
@@ -199,16 +206,19 @@ calc_easter_sunday(int year, int* dd, int* mm)
 
 	b = 255 - 11 * (year % 19);
 	d = ((b - 21) % 30) + 21;
-	if (d > 38) d -= 1;
-	e = (year + year/4 + d + 1) % 7;
+	if (d > 38)
+		d -= 1;
+	e = (year + year / 4 + d + 1) % 7;
 	q = d + 7 - e;
 	if (q < 32)
 	{
-		*dd = q; *mm = 3;
+		*dd = q;
+		*mm = 3;
 	}
 	else
 	{
-		*dd = q - 31; *mm = 4;
+		*dd = q - 31;
+		*mm = 4;
 	}
 }
 
@@ -223,9 +233,9 @@ easter_holidays(DateADT day, int y, int m)
 	{
 		if (m == 3 || m == 4)
 		{
-			int easter_sunday_day;
-			int easter_sunday_month;
-			int easter_sunday;
+			int			easter_sunday_day;
+			int			easter_sunday_month;
+			int			easter_sunday;
 
 			calc_easter_sunday(y, &easter_sunday_day, &easter_sunday_month);
 			easter_sunday = date2j(y, easter_sunday_month, easter_sunday_day) - POSTGRES_EPOCH_JDATE;
@@ -253,17 +263,20 @@ easter_holidays(DateADT day, int y, int m)
 static DateADT
 ora_add_bizdays(DateADT day, int ndays)
 {
-	int d, dx;
-	int y, m, auxd;
+	int			d,
+				dx;
+	int			y,
+				m,
+				auxd;
 	holiday_desc hd;
 
-	d = j2day(day+POSTGRES_EPOCH_JDATE);
-	dx = ndays > 0? 1 : -1;
+	d = j2day(day + POSTGRES_EPOCH_JDATE);
+	dx = ndays > 0 ? 1 : -1;
 
 	while (ndays != 0)
 	{
-		d = (d+dx) % 7;
-		d = (d < 0) ? 6:d;
+		d = (d + dx) % 7;
+		d = (d < 0) ? 6 : d;
 		day += dx;
 		if ((1 << d) & nonbizdays)
 			continue;
@@ -293,30 +306,34 @@ ora_add_bizdays(DateADT day, int ndays)
 static int
 ora_diff_bizdays(DateADT day1, DateADT day2)
 {
-	int d, ndays;
-	int y, m, auxd;
+	int			d,
+				ndays;
+	int			y,
+				m,
+				auxd;
 	holiday_desc hd;
 
-	int loops = 0;
-	bool start_is_bizday = false;
+	int			loops = 0;
+	bool		start_is_bizday = false;
 
 	if (day1 > day2)
 	{
-		DateADT 	aux_day;
+		DateADT		aux_day;
 
 		aux_day = day1;
-		day1 = day2; day2 = aux_day;
+		day1 = day2;
+		day2 = aux_day;
 	}
 
 	/* d is incremented on start of cycle, so now I have to decrease one */
-	d = j2day(day1+POSTGRES_EPOCH_JDATE-1);
+	d = j2day(day1 + POSTGRES_EPOCH_JDATE - 1);
 	ndays = 0;
 
 	while (day1 <= day2)
 	{
 		loops++;
 		day1 += 1;
-		d = (d+1) % 7;
+		d = (d + 1) % 7;
 
 		if ((1 << d) & nonbizdays)
 			continue;
@@ -344,10 +361,10 @@ ora_diff_bizdays(DateADT day1, DateADT day2)
 	}
 
 	/*
-	 * decrease result when first day was bizday, but we don't want
-	 * calculate first day.
+	 * decrease result when first day was bizday, but we don't want calculate
+	 * first day.
 	 */
-	if ( start_is_bizday && !include_start && ndays > 0)
+	if (start_is_bizday && !include_start && ndays > 0)
 		ndays -= 1;
 
 	return ndays;
@@ -367,12 +384,12 @@ ora_diff_bizdays(DateADT day1, DateADT day2)
 
 
 Datum
-plvdate_add_bizdays (PG_FUNCTION_ARGS)
+plvdate_add_bizdays(PG_FUNCTION_ARGS)
 {
-	DateADT day = PG_GETARG_DATEADT(0);
-	int ndays = PG_GETARG_INT32(1);
+	DateADT		day = PG_GETARG_DATEADT(0);
+	int			ndays = PG_GETARG_INT32(1);
 
-	PG_RETURN_DATEADT(ora_add_bizdays(day,ndays));
+	PG_RETURN_DATEADT(ora_add_bizdays(day, ndays));
 }
 
 
@@ -388,10 +405,12 @@ plvdate_add_bizdays (PG_FUNCTION_ARGS)
  ****************************************************************/
 
 Datum
-plvdate_nearest_bizday (PG_FUNCTION_ARGS)
+plvdate_nearest_bizday(PG_FUNCTION_ARGS)
 {
-	DateADT dt = PG_GETARG_DATEADT(0);
-	DateADT d1, d2, res;
+	DateADT		dt = PG_GETARG_DATEADT(0);
+	DateADT		d1,
+				d2,
+				res;
 
 	d1 = ora_add_bizdays(dt, -1);
 	d2 = ora_add_bizdays(dt, 1);
@@ -417,11 +436,11 @@ plvdate_nearest_bizday (PG_FUNCTION_ARGS)
  ****************************************************************/
 
 Datum
-plvdate_next_bizday (PG_FUNCTION_ARGS)
+plvdate_next_bizday(PG_FUNCTION_ARGS)
 {
-	DateADT day = PG_GETARG_DATEADT(0);
+	DateADT		day = PG_GETARG_DATEADT(0);
 
-	PG_RETURN_DATEADT(ora_add_bizdays(day,1));
+	PG_RETURN_DATEADT(ora_add_bizdays(day, 1));
 }
 
 
@@ -438,12 +457,12 @@ plvdate_next_bizday (PG_FUNCTION_ARGS)
  ****************************************************************/
 
 Datum
-plvdate_bizdays_between (PG_FUNCTION_ARGS)
+plvdate_bizdays_between(PG_FUNCTION_ARGS)
 {
-	DateADT day1 = PG_GETARG_DATEADT(0);
-	DateADT day2 = PG_GETARG_DATEADT(1);
+	DateADT		day1 = PG_GETARG_DATEADT(0);
+	DateADT		day2 = PG_GETARG_DATEADT(1);
 
-	PG_RETURN_INT32(ora_diff_bizdays(day1,day2));
+	PG_RETURN_INT32(ora_diff_bizdays(day1, day2));
 }
 
 
@@ -460,11 +479,11 @@ plvdate_bizdays_between (PG_FUNCTION_ARGS)
  ****************************************************************/
 
 Datum
-plvdate_prev_bizday (PG_FUNCTION_ARGS)
+plvdate_prev_bizday(PG_FUNCTION_ARGS)
 {
-	DateADT day = PG_GETARG_DATEADT(0);
+	DateADT		day = PG_GETARG_DATEADT(0);
 
-	PG_RETURN_DATEADT(ora_add_bizdays(day,-1));
+	PG_RETURN_DATEADT(ora_add_bizdays(day, -1));
 }
 
 
@@ -480,13 +499,15 @@ plvdate_prev_bizday (PG_FUNCTION_ARGS)
  ****************************************************************/
 
 Datum
-plvdate_isbizday (PG_FUNCTION_ARGS)
+plvdate_isbizday(PG_FUNCTION_ARGS)
 {
-	DateADT day = PG_GETARG_DATEADT(0);
-	int y, m, d;
+	DateADT		day = PG_GETARG_DATEADT(0);
+	int			y,
+				m,
+				d;
 	holiday_desc hd;
 
-	if (0 != ((1 << j2day(day+POSTGRES_EPOCH_JDATE)) & nonbizdays))
+	if (0 != ((1 << j2day(day + POSTGRES_EPOCH_JDATE)) & nonbizdays))
 		return false;
 
 	if (NULL != bsearch(&day, exceptions, exceptions_c,
@@ -494,13 +515,14 @@ plvdate_isbizday (PG_FUNCTION_ARGS)
 		return false;
 
 	j2date(day + POSTGRES_EPOCH_JDATE, &y, &m, &d);
-	hd.month = m; hd.day = d;
+	hd.month = m;
+	hd.day = d;
 
 	if (easter_holidays(day, y, m))
 		return false;
 
-	PG_RETURN_BOOL (NULL == bsearch(&hd, holidays, holidays_c,
-									sizeof(holiday_desc), holiday_desc_comp));
+	PG_RETURN_BOOL(NULL == bsearch(&hd, holidays, holidays_c,
+								   sizeof(holiday_desc), holiday_desc_comp));
 }
 
 
@@ -516,22 +538,23 @@ plvdate_isbizday (PG_FUNCTION_ARGS)
  ****************************************************************/
 
 Datum
-plvdate_set_nonbizday_dow (PG_FUNCTION_ARGS)
+plvdate_set_nonbizday_dow(PG_FUNCTION_ARGS)
 {
 	unsigned char check;
 
-	text *day_txt = PG_GETARG_TEXT_PP(0);
+	text	   *day_txt = PG_GETARG_TEXT_PP(0);
+
+	int			d = ora_seq_search(VARDATA_ANY(day_txt), ora_days, VARSIZE_ANY_EXHDR(day_txt));
 
-	int d = ora_seq_search(VARDATA_ANY(day_txt), ora_days, VARSIZE_ANY_EXHDR(day_txt));
 	CHECK_SEQ_SEARCH(d, "DAY/Day/day");
 
 	check = nonbizdays | (1 << d);
 	if (check == 0x7f)
 		ereport(ERROR,
-			    (errcode(ERRCODE_DATA_EXCEPTION),
-			     errmsg("nonbizday registration error"),
-			     errdetail("Constraint violation."),
-			     errhint("One day in week have to be bizday.")));
+				(errcode(ERRCODE_DATA_EXCEPTION),
+				 errmsg("nonbizday registration error"),
+				 errdetail("Constraint violation."),
+				 errhint("One day in week have to be bizday.")));
 
 	nonbizdays = nonbizdays | (1 << d);
 
@@ -550,11 +573,12 @@ plvdate_set_nonbizday_dow (PG_FUNCTION_ARGS)
  ****************************************************************/
 
 Datum
-plvdate_unset_nonbizday_dow (PG_FUNCTION_ARGS)
+plvdate_unset_nonbizday_dow(PG_FUNCTION_ARGS)
 {
-	text *day_txt = PG_GETARG_TEXT_PP(0);
+	text	   *day_txt = PG_GETARG_TEXT_PP(0);
+
+	int			d = ora_seq_search(VARDATA_ANY(day_txt), ora_days, VARSIZE_ANY_EXHDR(day_txt));
 
-	int d = ora_seq_search(VARDATA_ANY(day_txt), ora_days, VARSIZE_ANY_EXHDR(day_txt));
 	CHECK_SEQ_SEARCH(d, "DAY/Day/day");
 
 	nonbizdays = (nonbizdays | (1 << d)) ^ (1 << d);
@@ -576,30 +600,33 @@ plvdate_unset_nonbizday_dow (PG_FUNCTION_ARGS)
  ****************************************************************/
 
 Datum
-plvdate_set_nonbizday_day (PG_FUNCTION_ARGS)
+plvdate_set_nonbizday_day(PG_FUNCTION_ARGS)
 {
-	DateADT arg1 = PG_GETARG_DATEADT(0);
-	bool arg2 = PG_GETARG_BOOL(1);
-	int y, m, d;
+	DateADT		arg1 = PG_GETARG_DATEADT(0);
+	bool		arg2 = PG_GETARG_BOOL(1);
+	int			y,
+				m,
+				d;
 	holiday_desc hd;
 
 	if (arg2)
 	{
 		if (holidays_c == MAX_holidays)
 			ereport(ERROR,
-				    (errcode(ERRCODE_PROGRAM_LIMIT_EXCEEDED),
-				     errmsg("nonbizday registration error"),
-				     errdetail("Too much registered nonbizdays."),
-				     errhint("Increase MAX_holidays in 'plvdate.c'.")));
+					(errcode(ERRCODE_PROGRAM_LIMIT_EXCEEDED),
+					 errmsg("nonbizday registration error"),
+					 errdetail("Too much registered nonbizdays."),
+					 errhint("Increase MAX_holidays in 'plvdate.c'.")));
 
 		j2date(arg1 + POSTGRES_EPOCH_JDATE, &y, &m, &d);
-		hd.month = m; hd.day = d;
+		hd.month = m;
+		hd.day = d;
 
 		if (NULL != bsearch(&hd, holidays, holidays_c, sizeof(holiday_desc), holiday_desc_comp))
 			ereport(ERROR,
-				    (errcode(ERRCODE_DUPLICATE_OBJECT),
-				     errmsg("nonbizday registration error"),
-				     errdetail("Date is registered.")));
+					(errcode(ERRCODE_DUPLICATE_OBJECT),
+					 errmsg("nonbizday registration error"),
+					 errdetail("Date is registered.")));
 
 		holidays[holidays_c].month = m;
 		holidays[holidays_c].day = d;
@@ -611,16 +638,16 @@ plvdate_set_nonbizday_day (PG_FUNCTION_ARGS)
 	{
 		if (exceptions_c == MAX_EXCEPTIONS)
 			ereport(ERROR,
-				    (errcode(ERRCODE_PROGRAM_LIMIT_EXCEEDED),
-				     errmsg("nonbizday registration error"),
-				     errdetail("Too much registered nonrepeated nonbizdays."),
-				     errhint("Increase MAX_EXCEPTIONS in 'plvdate.c'.")));
+					(errcode(ERRCODE_PROGRAM_LIMIT_EXCEEDED),
+					 errmsg("nonbizday registration error"),
+					 errdetail("Too much registered nonrepeated nonbizdays."),
+					 errhint("Increase MAX_EXCEPTIONS in 'plvdate.c'.")));
 
 		if (NULL != bsearch(&arg1, exceptions, exceptions_c, sizeof(DateADT), dateadt_comp))
 			ereport(ERROR,
-				    (errcode(ERRCODE_DUPLICATE_OBJECT),
-				     errmsg("nonbizday registration error"),
-				     errdetail("Date is registered.")));
+					(errcode(ERRCODE_DUPLICATE_OBJECT),
+					 errmsg("nonbizday registration error"),
+					 errdetail("Date is registered.")));
 
 		exceptions[exceptions_c++] = arg1;
 		qsort(exceptions, exceptions_c, sizeof(DateADT), dateadt_comp);
@@ -643,13 +670,15 @@ plvdate_set_nonbizday_day (PG_FUNCTION_ARGS)
  ****************************************************************/
 
 Datum
-plvdate_unset_nonbizday_day (PG_FUNCTION_ARGS)
+plvdate_unset_nonbizday_day(PG_FUNCTION_ARGS)
 {
-	DateADT arg1 = PG_GETARG_DATEADT(0);
-	bool arg2 = PG_GETARG_BOOL(1);
-	int y, m, d;
-	bool found = false;
-	int i;
+	DateADT		arg1 = PG_GETARG_DATEADT(0);
+	bool		arg2 = PG_GETARG_BOOL(1);
+	int			y,
+				m,
+				d;
+	bool		found = false;
+	int			i;
 
 	if (arg2)
 	{
@@ -660,8 +689,8 @@ plvdate_unset_nonbizday_day (PG_FUNCTION_ARGS)
 				found = true;
 			else if (found)
 			{
-				holidays[i-1].month = holidays[i].month;
-				holidays[i-1].day = holidays[i].day;
+				holidays[i - 1].month = holidays[i].month;
+				holidays[i - 1].day = holidays[i].day;
 			}
 		}
 		if (found)
@@ -673,15 +702,15 @@ plvdate_unset_nonbizday_day (PG_FUNCTION_ARGS)
 			if (!found && exceptions[i] == arg1)
 				found = true;
 			else if (found)
-				exceptions[i-1] = exceptions[i];
+				exceptions[i - 1] = exceptions[i];
 		if (found)
 			exceptions_c -= 1;
 	}
 	if (!found)
 		ereport(ERROR,
-			    (errcode(ERRCODE_UNDEFINED_OBJECT),
-			     errmsg("nonbizday unregistration error"),
-			     errdetail("Nonbizday not found.")));
+				(errcode(ERRCODE_UNDEFINED_OBJECT),
+				 errmsg("nonbizday unregistration error"),
+				 errdetail("Nonbizday not found.")));
 
 	PG_RETURN_VOID();
 }
@@ -701,7 +730,7 @@ plvdate_unset_nonbizday_day (PG_FUNCTION_ARGS)
  ****************************************************************/
 
 Datum
-plvdate_use_easter (PG_FUNCTION_ARGS)
+plvdate_use_easter(PG_FUNCTION_ARGS)
 {
 	use_easter = PG_GETARG_BOOL(0);
 
@@ -721,7 +750,7 @@ plvdate_use_easter (PG_FUNCTION_ARGS)
  ****************************************************************/
 
 Datum
-plvdate_using_easter (PG_FUNCTION_ARGS)
+plvdate_using_easter(PG_FUNCTION_ARGS)
 {
 	PG_RETURN_BOOL(use_easter);
 }
@@ -741,7 +770,7 @@ plvdate_using_easter (PG_FUNCTION_ARGS)
  ****************************************************************/
 
 Datum
-plvdate_use_great_friday (PG_FUNCTION_ARGS)
+plvdate_use_great_friday(PG_FUNCTION_ARGS)
 {
 	use_great_friday = PG_GETARG_BOOL(0);
 
@@ -761,7 +790,7 @@ plvdate_use_great_friday (PG_FUNCTION_ARGS)
  ****************************************************************/
 
 Datum
-plvdate_using_great_friday (PG_FUNCTION_ARGS)
+plvdate_using_great_friday(PG_FUNCTION_ARGS)
 {
 	PG_RETURN_BOOL(use_great_friday);
 }
@@ -781,7 +810,7 @@ plvdate_using_great_friday (PG_FUNCTION_ARGS)
  ****************************************************************/
 
 Datum
-plvdate_include_start (PG_FUNCTION_ARGS)
+plvdate_include_start(PG_FUNCTION_ARGS)
 {
 	include_start = PG_GETARG_BOOL(0);
 
@@ -801,7 +830,7 @@ plvdate_include_start (PG_FUNCTION_ARGS)
  ****************************************************************/
 
 Datum
-plvdate_including_start (PG_FUNCTION_ARGS)
+plvdate_including_start(PG_FUNCTION_ARGS)
 {
 	PG_RETURN_BOOL(include_start);
 }
@@ -813,9 +842,9 @@ plvdate_including_start (PG_FUNCTION_ARGS)
  */
 
 Datum
-plvdate_default_holidays (PG_FUNCTION_ARGS)
+plvdate_default_holidays(PG_FUNCTION_ARGS)
 {
-	text *country = PG_GETARG_TEXT_PP(0);
+	text	   *country = PG_GETARG_TEXT_PP(0);
 
 	country_id = ora_seq_search(VARDATA_ANY(country), states, VARSIZE_ANY_EXHDR(country));
 	CHECK_SEQ_SEARCH(country_id, "STATE/State/state");
@@ -826,7 +855,7 @@ plvdate_default_holidays (PG_FUNCTION_ARGS)
 	exceptions_c = 0;
 
 	holidays_c = defaults_ci[country_id].holidays_c;
-	memcpy(holidays, defaults_ci[country_id].holidays, holidays_c*sizeof(holiday_desc));
+	memcpy(holidays, defaults_ci[country_id].holidays, holidays_c * sizeof(holiday_desc));
 
 	PG_RETURN_VOID();
 }
@@ -836,7 +865,7 @@ plvdate_default_holidays (PG_FUNCTION_ARGS)
  */
 
 Datum
-plvdate_version (PG_FUNCTION_ARGS)
+plvdate_version(PG_FUNCTION_ARGS)
 {
 	PG_RETURN_CSTRING(PLVDATE_VERSION);
 }
@@ -856,13 +885,15 @@ plvdate_version (PG_FUNCTION_ARGS)
 Datum
 plvdate_days_inmonth(PG_FUNCTION_ARGS)
 {
-	DateADT day = PG_GETARG_DATEADT(0);
-	int result;
-	int y, m, d;
+	DateADT		day = PG_GETARG_DATEADT(0);
+	int			result;
+	int			y,
+				m,
+				d;
 
 	j2date(day + POSTGRES_EPOCH_JDATE, &y, &m, &d);
 
-	result = date2j(y, m+1, 1) - date2j(y, m, 1);
+	result = date2j(y, m + 1, 1) - date2j(y, m, 1);
 
 	PG_RETURN_INT32(result);
 }
@@ -882,12 +913,14 @@ plvdate_days_inmonth(PG_FUNCTION_ARGS)
 Datum
 plvdate_isleapyear(PG_FUNCTION_ARGS)
 {
-	DateADT day = PG_GETARG_DATEADT(0);
-	int y, m, d;
-	bool result;
+	DateADT		day = PG_GETARG_DATEADT(0);
+	int			y,
+				m,
+				d;
+	bool		result;
 
 	j2date(day + POSTGRES_EPOCH_JDATE, &y, &m, &d);
-	result = ((( y % 4) == 0) && ((y % 100) != 0)) || ((y % 400) == 0);
+	result = (((y % 4) == 0) && ((y % 100) != 0)) || ((y % 400) == 0);
 
 	PG_RETURN_BOOL(result);
 }
